.. ambient documentation master file, created by
   sphinx-quickstart on Thu Jan 23 20:30:57 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ambient's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   air
   constructions
   materials
   material_data
   solar
   time


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
